Coverage report

File | function | statements | missing | excluded | branches | partial | coverage
--- | --- | --- | --- | --- | --- | --- | ---
src/pytest_vulture/__init__.py | VultureError.__init__ | 2 | 2 | 0 | 0 | 0 | 0.00%
src/pytest_vulture/conf/base.py | Configuration._get_parameters | 2 | 2 | 0 | 0 | 0 | 0.00%
src/pytest_vulture/conf/package.py | PackageConfiguration.setup_path | 1 | 1 | 0 | 0 | 0 | 0.00%
src/pytest_vulture/conf/package.py | PackageConfiguration.read_tomli | 4 | 4 | 2 | 0 | 0 | 0.00%
src/pytest_vulture/conf/reader.py | IniReader.read_ini | 11 | 5 | 0 | 4 | 1 | 60.00%
src/pytest_vulture/conf/vulture.py | VultureConfiguration.read_tomli | 6 | 6 | 2 | 0 | 0 | 0.00%
src/pytest_vulture/setup_manager.py | SetupManager._python_path | 11 | 0 | 0 | 2 | 1 | 92.31%
src/pytest_vulture/setup_manager.py | SetupManager._find_py_project_toml | 7 | 7 | 0 | 2 | 0 | 0.00%
src/pytest_vulture/setup_manager.py | SetupManager._generate_entry_points | 14 | 2 | 0 | 8 | 2 | 81.82%
src/pytest_vulture/setup_manager.py | SetupManager.__parse_entry_point_line | 8 | 3 | 2 | 4 | 1 | 50.00%
src/pytest_vulture/setup_manager.py | SetupManager.__check_entry_points | 21 | 8 | 2 | 8 | 3 | 62.07%
src/pytest_vulture/setup_manager.py | SetupManager.__generate_root_paths | 11 | 5 | 0 | 4 | 2 | 53.33%
src/pytest_vulture/vulture/manager.py | VultureManager.get_file_errors | 7 | 7 | 0 | 6 | 0 | 0.00%
src/pytest_vulture/vulture/manager.py | VultureManager.__filter_results | 4 | 2 | 0 | 4 | 1 | 37.50%
src/pytest_vulture/vulture/manager.py | VultureManager.__check_path | 4 | 4 | 0 | 2 | 0 | 0.00%
src/pytest_vulture/vulture/manager.py | VultureManager.__path_equals | 3 | 3 | 0 | 0 | 0 | 0.00%
Total |  | 309 | 61 | 20 | 48 | 11 | 75.91%

No items found using the specified filter.

35 functions skipped due to complete coverage.